<template>
  <textarea
    :id="id"
    :autocomplete="autocomplete"
    :class="classes"
    :cols="cols"
    :name="name"
    :placeholder="placeholder"
    :required="required"
    :rows="rows"
    :value="modelValue"
    class="block w-full rounded-md border-0 py-1.5 text-sm text-gray-900 ring-1 ring-inset ring-gray-900/10 placeholder:text-gray-400 focus:outline-none focus:ring-2 focus:ring-primary-500 sm:leading-6"
    @input="$emit('update:modelValue', ($event.target as HTMLInputElement).value as string | undefined)"
  />
</template>

<script lang="ts" setup>
import type { ComputedRef } from "vue";

withDefaults(
  defineProps<{
    name: string;
    modelValue: string | undefined;
    required?: boolean;
    placeholder?: string;
    autocomplete?: string;
    rows?: number;
    cols?: number;
  }>(),
  {
    placeholder: undefined,
    autocomplete: undefined,
    rows: undefined,
    cols: undefined,
  },
);

defineEmits<{
  "update:modelValue": [value: string | undefined];
}>();

const id = inject<string | undefined>("id", undefined);
const errors = inject<ComputedRef<boolean> | undefined>("errors", undefined);

const classes = computed(() => ({
  "ring-gray-900/10": !errors?.value,
  "text-red-600 ring-red-500 placeholder:text-red-400 focus:ring-red-600": errors?.value,
}));
</script>
